==> ggtree_1.16.0.tar.gz: ggtree/R/reexports.R <==
##' @importFrom magrittr %>%
##' @export
magrittr::`%>%`

##' @importFrom ape rtree
##' @export
ape::rtree

##' @importFrom ape read.tree
##' @export
ape::read.tree

##' @importFrom ape read.nexus
##' @export
ape::read.nexus

##' @importFrom tidytree groupOTU
##' @export
tidytree::groupOTU

##' @importFrom tidytree groupClade
##' @export
tidytree::groupClade

##' @importFrom dplyr collapse
##' @export
dplyr::collapse

##' @importFrom ggplot2 fortify
##' @export
ggplot2::fortify

##' @importFrom ggplot2 ggplot
##' @export
ggplot2::ggplot

##' @importFrom ggplot2 xlim
##' @export
ggplot2::xlim

##' @importFrom ggplot2 theme
##' @export
ggplot2::theme

##' @importFrom ggplot2 ggsave
##' @export
ggplot2::ggsave

##' @importFrom ggplot2 aes
##' @export
ggplot2::aes

##' @importFrom ggplot2 fortify
##' @export
ggplot2::fortify

##' @importFrom ggplot2 geom_text
##' @export
ggplot2::geom_text

##' @importFrom ggplot2 geom_label
##' @export
ggplot2::geom_label

##' @importFrom ggplot2 geom_point
##' @export
ggplot2::geom_point


##' @importFrom treeio read.astral
##' @export
treeio::read.astral


##' @importFrom treeio read.beast
##' @export
treeio::read.beast

##' @importFrom treeio read.codeml
##' @export
treeio::read.codeml

##' @importFrom treeio read.codeml_mlc
##' @export
treeio::read.codeml_mlc

##' @importFrom treeio read.hyphy
##' @export
treeio::read.hyphy

##' @importFrom treeio read.iqtree
##' @export
treeio::read.iqtree

##' @importFrom treeio read.jplace
##' @export
treeio::read.jplace

##' @importFrom treeio read.jtree
##' @export
treeio::read.jtree

##' @importFrom treeio read.mrbayes
##' @export
treeio::read.mrbayes

##' @importFrom treeio read.newick
##' @export
treeio::read.newick

##' @importFrom treeio read.nhx
##' @export
treeio::read.nhx

##' @importFrom treeio read.paml_rst
##' @export
treeio::read.paml_rst

##' @importFrom treeio read.phylip
##' @export
treeio::read.phylip

##' @importFrom treeio read.phyloT
##' @export
treeio::read.phyloT

##' @importFrom treeio read.r8s
##' @export
treeio::read.r8s

##' @importFrom treeio read.raxml
##' @export
treeio::read.raxml

==> ggtree_3.1.6.tar.gz: ggtree/R/reexports.R <==
##' @importFrom magrittr %>%
##' @export
magrittr::`%>%`

##' @importFrom ape rtree
##' @export
ape::rtree

##' @importFrom ape read.tree
##' @export
ape::read.tree

##' @importFrom tidytree groupOTU
##' @export
tidytree::groupOTU

##' @importFrom tidytree groupClade
##' @export
tidytree::groupClade

##' @importFrom tidytree nodeid
##' @export
tidytree::nodeid

##' @importFrom tidytree nodelab
##' @export
tidytree::nodelab

##' @importFrom tidytree MRCA
##' @export
tidytree::MRCA

##' @importFrom dplyr collapse
##' @export
dplyr::collapse

##' @importFrom ggplot2 fortify
##' @export
ggplot2::fortify

##' @importFrom ggplot2 ggplot
##' @export
ggplot2::ggplot

##' @importFrom ggplot2 xlim
##' @export
ggplot2::xlim

##' @importFrom ggplot2 theme
##' @export
ggplot2::theme

##' @importFrom ggplot2 ggsave
##' @export
ggplot2::ggsave

##' @importFrom ggplot2 aes
##' @export
ggplot2::aes

##' @importFrom ggplot2 geom_text
##' @export
ggplot2::geom_text

##' @importFrom ggplot2 geom_label
##' @export
ggplot2::geom_label

##' @importFrom ggplot2 geom_point
##' @export
ggplot2::geom_point

##' @importFrom ggplot2 guide_legend
##' @export
ggplot2::guide_legend

##' @importFrom ggplot2 scale_colour_manual
##' @export
ggplot2::scale_colour_manual

##' @importFrom ggplot2 scale_color_manual
##' @export
ggplot2::scale_color_manual

##' @importFrom ggplot2 scale_fill_manual
##' @export
ggplot2::scale_fill_manual

##' @importFrom ggplot2 margin
##' @export
ggplot2::margin

##' @importFrom grid arrow
##' @export
grid::arrow

##' @importFrom grid unit
##' @export
grid::unit
